@@ -9,27 +9,47 @@ Usage::
         Client,
         EndpointDeletedWaiter,
         EndpointInServiceWaiter,
+        ListActionsPaginator,
         ListAlgorithmsPaginator,
+        ListAppImageConfigsPaginator,
         ListAppsPaginator,
+        ListArtifactsPaginator,
+        ListAssociationsPaginator,
         ListAutoMLJobsPaginator,
         ListCandidatesForAutoMLJobPaginator,
         ListCodeRepositoriesPaginator,
         ListCompilationJobsPaginator,
+        ListContextsPaginator,
+        ListDataQualityJobDefinitionsPaginator,
+        ListDeviceFleetsPaginator,
+        ListDevicesPaginator,
         ListDomainsPaginator,
+        ListEdgePackagingJobsPaginator,
         ListEndpointConfigsPaginator,
         ListEndpointsPaginator,
         ListExperimentsPaginator,
+        ListFeatureGroupsPaginator,
         ListFlowDefinitionsPaginator,
         ListHumanTaskUisPaginator,
         ListHyperParameterTuningJobsPaginator,
+        ListImageVersionsPaginator,
+        ListImagesPaginator,
         ListLabelingJobsForWorkteamPaginator,
         ListLabelingJobsPaginator,
+        ListModelBiasJobDefinitionsPaginator,
+        ListModelExplainabilityJobDefinitionsPaginator,
+        ListModelPackageGroupsPaginator,
         ListModelPackagesPaginator,
+        ListModelQualityJobDefinitionsPaginator,
         ListModelsPaginator,
         ListMonitoringExecutionsPaginator,
         ListMonitoringSchedulesPaginator,
         ListNotebookInstanceLifecycleConfigsPaginator,
         ListNotebookInstancesPaginator,
+        ListPipelineExecutionStepsPaginator,
+        ListPipelineExecutionsPaginator,
+        ListPipelineParametersForExecutionPaginator,
+        ListPipelinesPaginator,
         ListProcessingJobsPaginator,
         ListSubscribedWorkteamsPaginator,
         ListTagsPaginator,
@@ -39,6 +59,7 @@ Usage::
         ListTrialComponentsPaginator,
         ListTrialsPaginator,
         ListUserProfilesPaginator,
+        ListWorkforcesPaginator,
         ListWorkteamsPaginator,
         NotebookInstanceDeletedWaiter,
         NotebookInstanceInServiceWaiter,
@@ -64,27 +85,47 @@ Usage::
     training_job_completed_or_stopped_waiter: TrainingJobCompletedOrStoppedWaiter = client.get_waiter("training_job_completed_or_stopped")
     transform_job_completed_or_stopped_waiter: TransformJobCompletedOrStoppedWaiter = client.get_waiter("transform_job_completed_or_stopped")
 
+    list_actions_paginator: ListActionsPaginator = client.get_paginator("list_actions")
     list_algorithms_paginator: ListAlgorithmsPaginator = client.get_paginator("list_algorithms")
+    list_app_image_configs_paginator: ListAppImageConfigsPaginator = client.get_paginator("list_app_image_configs")
     list_apps_paginator: ListAppsPaginator = client.get_paginator("list_apps")
+    list_artifacts_paginator: ListArtifactsPaginator = client.get_paginator("list_artifacts")
+    list_associations_paginator: ListAssociationsPaginator = client.get_paginator("list_associations")
     list_auto_ml_jobs_paginator: ListAutoMLJobsPaginator = client.get_paginator("list_auto_ml_jobs")
     list_candidates_for_auto_ml_job_paginator: ListCandidatesForAutoMLJobPaginator = client.get_paginator("list_candidates_for_auto_ml_job")
     list_code_repositories_paginator: ListCodeRepositoriesPaginator = client.get_paginator("list_code_repositories")
     list_compilation_jobs_paginator: ListCompilationJobsPaginator = client.get_paginator("list_compilation_jobs")
+    list_contexts_paginator: ListContextsPaginator = client.get_paginator("list_contexts")
+    list_data_quality_job_definitions_paginator: ListDataQualityJobDefinitionsPaginator = client.get_paginator("list_data_quality_job_definitions")
+    list_device_fleets_paginator: ListDeviceFleetsPaginator = client.get_paginator("list_device_fleets")
+    list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
     list_domains_paginator: ListDomainsPaginator = client.get_paginator("list_domains")
+    list_edge_packaging_jobs_paginator: ListEdgePackagingJobsPaginator = client.get_paginator("list_edge_packaging_jobs")
     list_endpoint_configs_paginator: ListEndpointConfigsPaginator = client.get_paginator("list_endpoint_configs")
     list_endpoints_paginator: ListEndpointsPaginator = client.get_paginator("list_endpoints")
     list_experiments_paginator: ListExperimentsPaginator = client.get_paginator("list_experiments")
+    list_feature_groups_paginator: ListFeatureGroupsPaginator = client.get_paginator("list_feature_groups")
     list_flow_definitions_paginator: ListFlowDefinitionsPaginator = client.get_paginator("list_flow_definitions")
     list_human_task_uis_paginator: ListHumanTaskUisPaginator = client.get_paginator("list_human_task_uis")
     list_hyper_parameter_tuning_jobs_paginator: ListHyperParameterTuningJobsPaginator = client.get_paginator("list_hyper_parameter_tuning_jobs")
+    list_image_versions_paginator: ListImageVersionsPaginator = client.get_paginator("list_image_versions")
+    list_images_paginator: ListImagesPaginator = client.get_paginator("list_images")
     list_labeling_jobs_paginator: ListLabelingJobsPaginator = client.get_paginator("list_labeling_jobs")
     list_labeling_jobs_for_workteam_paginator: ListLabelingJobsForWorkteamPaginator = client.get_paginator("list_labeling_jobs_for_workteam")
+    list_model_bias_job_definitions_paginator: ListModelBiasJobDefinitionsPaginator = client.get_paginator("list_model_bias_job_definitions")
+    list_model_explainability_job_definitions_paginator: ListModelExplainabilityJobDefinitionsPaginator = client.get_paginator("list_model_explainability_job_definitions")
+    list_model_package_groups_paginator: ListModelPackageGroupsPaginator = client.get_paginator("list_model_package_groups")
     list_model_packages_paginator: ListModelPackagesPaginator = client.get_paginator("list_model_packages")
+    list_model_quality_job_definitions_paginator: ListModelQualityJobDefinitionsPaginator = client.get_paginator("list_model_quality_job_definitions")
     list_models_paginator: ListModelsPaginator = client.get_paginator("list_models")
     list_monitoring_executions_paginator: ListMonitoringExecutionsPaginator = client.get_paginator("list_monitoring_executions")
     list_monitoring_schedules_paginator: ListMonitoringSchedulesPaginator = client.get_paginator("list_monitoring_schedules")
     list_notebook_instance_lifecycle_configs_paginator: ListNotebookInstanceLifecycleConfigsPaginator = client.get_paginator("list_notebook_instance_lifecycle_configs")
     list_notebook_instances_paginator: ListNotebookInstancesPaginator = client.get_paginator("list_notebook_instances")
+    list_pipeline_execution_steps_paginator: ListPipelineExecutionStepsPaginator = client.get_paginator("list_pipeline_execution_steps")
+    list_pipeline_executions_paginator: ListPipelineExecutionsPaginator = client.get_paginator("list_pipeline_executions")
+    list_pipeline_parameters_for_execution_paginator: ListPipelineParametersForExecutionPaginator = client.get_paginator("list_pipeline_parameters_for_execution")
+    list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     list_processing_jobs_paginator: ListProcessingJobsPaginator = client.get_paginator("list_processing_jobs")
     list_subscribed_workteams_paginator: ListSubscribedWorkteamsPaginator = client.get_paginator("list_subscribed_workteams")
     list_tags_paginator: ListTagsPaginator = client.get_paginator("list_tags")
@@ -94,33 +135,54 @@ Usage::
     list_trial_components_paginator: ListTrialComponentsPaginator = client.get_paginator("list_trial_components")
     list_trials_paginator: ListTrialsPaginator = client.get_paginator("list_trials")
     list_user_profiles_paginator: ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
+    list_workforces_paginator: ListWorkforcesPaginator = client.get_paginator("list_workforces")
     list_workteams_paginator: ListWorkteamsPaginator = client.get_paginator("list_workteams")
     search_paginator: SearchPaginator = client.get_paginator("search")
     ```
 """
-from mypy_boto3_sagemaker.client import SageMakerClient, SageMakerClient as Client
-from mypy_boto3_sagemaker.paginator import (
+from .client import SageMakerClient
+from .paginator import (
+    ListActionsPaginator,
     ListAlgorithmsPaginator,
+    ListAppImageConfigsPaginator,
     ListAppsPaginator,
+    ListArtifactsPaginator,
+    ListAssociationsPaginator,
     ListAutoMLJobsPaginator,
     ListCandidatesForAutoMLJobPaginator,
     ListCodeRepositoriesPaginator,
     ListCompilationJobsPaginator,
+    ListContextsPaginator,
+    ListDataQualityJobDefinitionsPaginator,
+    ListDeviceFleetsPaginator,
+    ListDevicesPaginator,
     ListDomainsPaginator,
+    ListEdgePackagingJobsPaginator,
     ListEndpointConfigsPaginator,
     ListEndpointsPaginator,
     ListExperimentsPaginator,
+    ListFeatureGroupsPaginator,
     ListFlowDefinitionsPaginator,
     ListHumanTaskUisPaginator,
     ListHyperParameterTuningJobsPaginator,
+    ListImagesPaginator,
+    ListImageVersionsPaginator,
     ListLabelingJobsForWorkteamPaginator,
     ListLabelingJobsPaginator,
+    ListModelBiasJobDefinitionsPaginator,
+    ListModelExplainabilityJobDefinitionsPaginator,
+    ListModelPackageGroupsPaginator,
     ListModelPackagesPaginator,
+    ListModelQualityJobDefinitionsPaginator,
     ListModelsPaginator,
     ListMonitoringExecutionsPaginator,
     ListMonitoringSchedulesPaginator,
     ListNotebookInstanceLifecycleConfigsPaginator,
     ListNotebookInstancesPaginator,
+    ListPipelineExecutionsPaginator,
+    ListPipelineExecutionStepsPaginator,
+    ListPipelineParametersForExecutionPaginator,
+    ListPipelinesPaginator,
     ListProcessingJobsPaginator,
     ListSubscribedWorkteamsPaginator,
     ListTagsPaginator,
@@ -130,10 +192,11 @@ from mypy_boto3_sagemaker.paginator import (
     ListTrialComponentsPaginator,
     ListTrialsPaginator,
     ListUserProfilesPaginator,
+    ListWorkforcesPaginator,
     ListWorkteamsPaginator,
     SearchPaginator,
 )
-from mypy_boto3_sagemaker.waiter import (
+from .waiter import (
     EndpointDeletedWaiter,
     EndpointInServiceWaiter,
     NotebookInstanceDeletedWaiter,
@@ -144,32 +207,54 @@ from mypy_boto3_sagemaker.waiter import (
     TransformJobCompletedOrStoppedWaiter,
 )
 
+Client = SageMakerClient
+
 
 __all__ = (
     "Client",
     "EndpointDeletedWaiter",
     "EndpointInServiceWaiter",
+    "ListActionsPaginator",
     "ListAlgorithmsPaginator",
+    "ListAppImageConfigsPaginator",
     "ListAppsPaginator",
+    "ListArtifactsPaginator",
+    "ListAssociationsPaginator",
     "ListAutoMLJobsPaginator",
     "ListCandidatesForAutoMLJobPaginator",
     "ListCodeRepositoriesPaginator",
     "ListCompilationJobsPaginator",
+    "ListContextsPaginator",
+    "ListDataQualityJobDefinitionsPaginator",
+    "ListDeviceFleetsPaginator",
+    "ListDevicesPaginator",
     "ListDomainsPaginator",
+    "ListEdgePackagingJobsPaginator",
     "ListEndpointConfigsPaginator",
     "ListEndpointsPaginator",
     "ListExperimentsPaginator",
+    "ListFeatureGroupsPaginator",
     "ListFlowDefinitionsPaginator",
     "ListHumanTaskUisPaginator",
     "ListHyperParameterTuningJobsPaginator",
+    "ListImageVersionsPaginator",
+    "ListImagesPaginator",
     "ListLabelingJobsForWorkteamPaginator",
     "ListLabelingJobsPaginator",
+    "ListModelBiasJobDefinitionsPaginator",
+    "ListModelExplainabilityJobDefinitionsPaginator",
+    "ListModelPackageGroupsPaginator",
     "ListModelPackagesPaginator",
+    "ListModelQualityJobDefinitionsPaginator",
     "ListModelsPaginator",
     "ListMonitoringExecutionsPaginator",
     "ListMonitoringSchedulesPaginator",
     "ListNotebookInstanceLifecycleConfigsPaginator",
     "ListNotebookInstancesPaginator",
+    "ListPipelineExecutionStepsPaginator",
+    "ListPipelineExecutionsPaginator",
+    "ListPipelineParametersForExecutionPaginator",
+    "ListPipelinesPaginator",
     "ListProcessingJobsPaginator",
     "ListSubscribedWorkteamsPaginator",
     "ListTagsPaginator",
@@ -179,6 +264,7 @@ __all__ = (
     "ListTrialComponentsPaginator",
     "ListTrialsPaginator",
     "ListUserProfilesPaginator",
+    "ListWorkforcesPaginator",
     "ListWorkteamsPaginator",
     "NotebookInstanceDeletedWaiter",
     "NotebookInstanceInServiceWaiter",
